@@ -30,9 +30,8 @@ def _build_arguments():
 
 def start_example_task(test=False, args=None):
     argument_objs = _build_arguments()
-    log.info("Input args:{}".format(str(args)))
-    args = ["-h"] if not args else args
-    task_name, arguments = ComplexArguments(argument_objs).parse(args)
+
+    task_name, arguments = ComplexArguments(argument_objs).parse()
     arguments.taskArgs.model_args.unit_test = test
     log.info("Start Example Task:{}, with arguments:{}".format(task_name, str(arguments.taskArgs)))
     task_action = arguments.runArgs.action
