@@ -38,16 +38,22 @@ class TaskModel:
         self._init()
 
     def _init(self):
-        self._model_args.validate()
         self.task_model = self._build_task_model(self._model_args, self._user_model_class)
         log.info("Loading the task model: " + str(self.task_model))
 
-        self.config, self.tokenizer, self.model = self.task_model.load(num_labels=self._model_args.num_labels)
+        self.config, self.tokenizer, self.model = self.task_model.load(
+            num_labels=self._model_args.num_labels,
+            unit_test=self._model_args.unit_test)
 
         log.info(
             "Loaded task model, config: {}, tokenizer: {}, model: {} ".format(type(self.config), type(self.tokenizer),
                                                                               type(self.model)))
 
+        self._freeze_parameters()
+
+    def _freeze_parameters(self):
+        if not self.model:
+            return
         parameters = eval("self.model." + self._model_args.freeze_parameter + '.parameters()')
 
         for param in parameters:
