@@ -17,4 +17,4 @@ class TestTransformersxTask:
         assert isinstance(taskModel.tokenizer, (BertTokenizer))
 
     def test_start_example_task(self):
-        start_example_task(True, ["news", "-h"])
+        start_example_task(True)
